# MIDI-Transformer

This is another implementation of the paper "Compound Word Transformer: Learning to Compose Full-Song Music over Dynamic Directed Hypergraphs" in pyTorch.

You can see the original implementation [here](https://github.com/YatingMusic/compound-word-transformer)
<br />

## Features
- using Deepnote package as the interface to work with midi files
- using pytorch lightning makes it super easy to train with any configuration
- clean, modular code
- config-based experiment

## Install
```
git clone https://github.com/s-omranpour/MIDI-Transformer
cd MIDI-Transformer
pip install .
```


## Getting started
Visit examples directory.
